# bioinf_common

Aggregation of functionalities needed in multiple projects.


## Installation

First install the following C++ dependencies:
* `armadillo`

Then execute:
```bash
$ ./install.sh
```


## Tests

```bash
$ tox
```
